from rich.console import Console
from rich.table import Table
from pdf_crop.crop_pymupdf import PymuPDFCrop
from pdf_crop.helper import rect_str


def crop(input_file, page_option: list):
    table = Table(title="PDF Crop Summary", leading=0)
    table.add_column("Page No.", justify="right", style="cyan", no_wrap=True)
    table.add_column("MediaBox", justify="right", style="magenta")
    table.add_column("CropBox", justify="right", style="magenta")
    table.add_column("Output", justify="right", style="green")

    space, threshold = (5, 0.008)
    for option in page_option:
        page_no, output_file = option[:2]
        if len(option) > 2:
            space = option[2]
        if len(option) > 3:
            space = option[3]
        pdf_crop = PymuPDFCrop(input_file=input_file, space=space, threshold=threshold)
        output_file, media_box, crop_box = pdf_crop.crop(page_no, output_file=output_file, crop_box=None)
        table.add_row(str(option[0]), rect_str(media_box), rect_str(crop_box), output_file)
    # Show summary
    console = Console()
    console.print(table)


from pathlib import Path
from setuptools import setup, find_packages
import io
import os


VERSION = "0.0.13"


def read(*paths, **kwargs):
    content = ""
    with io.open(
        os.path.join(os.path.dirname(__file__), *paths),
        encoding=kwargs.get("encoding", "utf8"),
    ) as open_file:
        content = open_file.read().strip()
    return content


def read_requirements(path):
    return [
        line.strip()
        for line in read(path).split("\n")
        if not line.startswith(('"', "#", "-", "git+"))
    ]

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="pdf_crop",
    long_description=long_description,
    long_description_content_type='text/markdown',
    version=VERSION,
    description="A commandline tool to crop a PDF into sub-PDFs",
    classifiers=[],
    keywords="PDF, Crop",
    author="wniu99",
    author_email="niuwei95@gmail.com",
    url="https://www.niuwei.info",
    license="FreeBSD",
    packages=find_packages(),
    include_package_data=True,
    zip_safe=True,
    install_requires=["pymupdf", "imageio", "rich", "numpy"],
    entry_points={"console_scripts": ["pdf_crop = pdf_crop.__main__:main"]},
)
